@@ -1,6 +1,6 @@
 /* ans.c - Interface for text2atm and atm2text to ANS */
 
-/* Written 1996-1999 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1996-2000 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 /*
@@ -209,10 +209,11 @@ static int cc_len(int p0,int p1)
 	    while (fgets(buffer,MAX_LINE,file)) {
 		here = strchr(buffer,'#');
 		if (here) *here = 0;
-		if (sscanf(buffer,"%d",&cc) == 1)
+		if (sscanf(buffer,"%d",&cc) == 1) {
 		    if (cc < 10) cc_table[cc] = 1;
 		    else if (cc < 100) cc_table[cc] = 2;
 			else cc_table[cc/10] = 3;
+		}
 	    }
 	    fclose(file);
 	}
