@@ -1,7 +1,7 @@
 /* proto.c - Common protocol functions and structures */
  
 /* Written 1997-1998 by Roman Pletka, EPFL-SSC */
-/* Modified 1998 by Werner Almesberger, EPFL ICA */
+/* Modified 1998,2000 by Werner Almesberger, EPFL ICA */
 
 
 #include <stdarg.h>
@@ -72,7 +72,7 @@ void send_listen(SIGNALING_ENTITY *sig)
     memset(&msg,0,sizeof(msg));
     /* compose the message */
     msg.type = as_listen;
-    msg.vcc = (unsigned long) sig;
+    *(unsigned long *) &msg.vcc = (unsigned long) sig;
     msg.svc.sas_family = AF_ATMSVC;
     msg.qos.aal = ATM_AAL5;
     msg.qos.txtp.traffic_class = msg.qos.rxtp.traffic_class = ATM_ANYCLASS;
@@ -90,8 +90,8 @@ void send_identify(CALL *call)
   
     /* compose the message */
     msg.type = as_identify;
-    msg.vcc = (unsigned long) call | CALLER;
-    msg.listen_vcc = (unsigned long) call->in.sig;
+    *(unsigned long *) &msg.vcc = (unsigned long) call | CALLER;
+    *(unsigned long *) &msg.listen_vcc = (unsigned long) call->in.sig;
   
     /* We have to complete the message (vci,vpi..) */
     msg.pvc = call->in.pvc;
@@ -107,7 +107,8 @@ void send_connect(CALL *call)
     memset(&msg,0,sizeof(msg));
     /* compose the message */
     msg.type = as_connect;
-    msg.vcc = (unsigned long) call | CALLED; /* some kind of magic... */
+    *(unsigned long *) &msg.vcc = (unsigned long) call | CALLED;
+      /* some kind of magic... */
     msg.local = call->in.svc;
     msg.qos.aal = call->in.qos.aal; /* or should we rather use out.qos ? @@@ */
     msg.qos.txtp = call->in.qos.rxtp;
@@ -127,7 +128,7 @@ void send_reject(CALL *call, int err_code)
     /*  this is always sent to caller */
     memset(&msg,0,sizeof(msg));
     msg.type = as_reject;
-    msg.vcc = (unsigned long) call | CALLER; 
+    *(unsigned long *) &msg.vcc = (unsigned long) call | CALLER; 
     msg.reply = err_code;
     sig_send(call->in.sig,&msg);
 }
@@ -140,7 +141,7 @@ void send_reject_not_id(SIGNALING_ENTITY *sig, int err_code)
     /*  this is always sent to caller */
     memset(&msg,0,sizeof(msg));
     msg.type = as_reject;
-    msg.listen_vcc = (unsigned long) sig; 
+    *(unsigned long *) &msg.listen_vcc = (unsigned long) sig; 
     msg.reply = err_code;
     sig_send(sig,&msg);
 }
@@ -152,7 +153,8 @@ void send_close(CALL *call,int dest)
 
     memset(&msg,0,sizeof(msg));
     msg.type = as_close;
-    msg.vcc = (unsigned long) call | dest; /* dest: CALLER or CALLED */
+    *(unsigned long *) &msg.vcc = (unsigned long) call | dest;
+      /* dest: CALLER or CALLED */
     /* msg.reply = ??!! */  
     sig_send(dest == CALLER ? call->in.sig : call->out.sig,&msg);
 }
@@ -164,7 +166,7 @@ void send_accept(CALL *call)
 
     memset(&msg,0,sizeof(msg));
     msg.type = as_accept;
-    msg.vcc = (unsigned long) call | CALLER;
+    *(unsigned long *) &msg.vcc = (unsigned long) call | CALLER;
     sig_send(call->in.sig,&msg);
 }
 
@@ -179,8 +181,8 @@ CALL *demux_in(unsigned long *srce, struct atmsvc_msg *msg)
      of the call pointer. We can do this, because the compiler aligns
      memory reservation to pointers with  3 ls-bits = 0. 
      */
-    *srce = (unsigned long) (msg->vcc & 3);
-    return (CALL *) (msg->vcc & ~3);
+    *srce = *(unsigned long *) &msg->vcc & 3;
+    return (CALL *) (*(unsigned long *) &msg->vcc & ~3);
 }
 
 /*****************************************************************************/
@@ -188,9 +190,9 @@ CALL *demux_in(unsigned long *srce, struct atmsvc_msg *msg)
 /*****************************************************************************/
 void print_msg(struct atmsvc_msg *msg, CALL *call,unsigned long source) {
   
-  printf("Msg '%s' received from %s vcc=%ld for call 0x%p, listen: %ld\n",
-	 as_msgs[msg->type], sources[source], msg->vcc, call,
-	 msg->listen_vcc);
+  printf("Msg '%s' received from %s vcc=%s for call 0x%p, listen: %s\n",
+	 as_msgs[msg->type], sources[source], kptr_print(&msg->vcc), call,
+	 kptr_print(&msg->listen_vcc));
 }
 void print_state(CALL *call) {
   printf("    Call 0x%p entered state '%s'\n", 
